Module interface_args

Module interface_args 

Data structures for describing the parameters of the various FF-A interfaces.

Structs

DirectMsg2Args
Arguments for the FFA_MSG_SEND_DIRECT_{REQ,RESP}2 interfaces.
LogChars
Generic type for storing FFA_CONSOLE_LOG character payload and its length in bytes.
MsgSend2Flags
Flags field of the FFA_MSG_SEND2 interface.
MsgWaitFlags
Flags field of the FFA_MSG_WAIT interface.
SuccessArgsFeatures
FFA_FEATURES specific success argument structure. This type needs further specialization based on ‘FF-A function ID or Feature ID’ field of the preceeding FFA_FEATURES request.
SuccessArgsIdGet
FFA_ID_GET specific success argument structure.
SuccessArgsSpmIdGet
FFA_SPM_ID_GET specific success argument structure.
TargetInfo
Endpoint ID and vCPU ID pair, used by FFA_ERROR, FFA_INTERRUPT and FFA_RUN interfaces.
VersionFlags
Flags for the FFA_VERSION interface.

Enums

ConsoleLogChars
Argument for the FFA_CONSOLE_LOG interface.
DirectMsgArgs
Arguments for the FFA_MSG_SEND_DIRECT_{REQ,RESP} interfaces.
Feature
Arguments for the FFA_FEATURES interface.
FeatureId
Feature IDs used by the FFA_FEATURES interface.
MemAddr
Memory address argument for FFA_MEM_PERM_{GET,SET} interfaces.
MemOpBuf
Descriptor for a dynamically allocated memory buffer that contains the memory transaction descriptor.
RxTxAddr
RXTX buffer descriptor, used by FFA_RXTX_MAP.
SecondaryEpRegisterAddr
Entrypoint address argument for FFA_SECONDARY_EP_REGISTER interface.
SuccessArgs
Generic arguments of the FFA_SUCCESS interface. The interpretation of the arguments depends on the interface that initiated the request. The application code has knowledge of the request, so it has to convert SuccessArgs into/from a specific success args structure that matches the request.
VersionQueryType
Version query types for the FFA_VERSION interface.
VmAvailabilityStatus
Composite type for capturing success and error return codes for the VM availability messages.
WarmBootType
Arguments for the Power Warm Boot FFA_MSG_SEND_DIRECT_REQ interface.

Type Aliases

ConsoleLogChars32
Specialized type for 32-bit FFA_CONSOLE_LOG payload.
ConsoleLogChars64
Specialized type for 64-bit FFA_CONSOLE_LOG payload.