MemOpBuf

Enum MemOpBuf 

pub enum MemOpBuf {
    Buf32 {
        addr: u32,
        page_cnt: u32,
    },
    Buf64 {
        addr: u64,
        page_cnt: u32,
    },
}
Descriptor for a dynamically allocated memory buffer that contains the memory transaction descriptor.

Used by FFA_MEM_{DONATE,LEND,SHARE,RETRIEVE_REQ} interfaces, only when the TX buffer is not used to transmit the transaction descriptor.

Variants



Buf32

Fields

addr: u32
page_cnt: u32


Buf64

Fields

addr: u64
page_cnt: u32