VersionQueryType

Enum VersionQueryType 

#[repr(u8)]
pub enum VersionQueryType { Negotiate = 0, QueryCompatibility = 1, QueryNegotiated = 2, }
Version query types for the FFA_VERSION interface.

Variants



Negotiate = 0

Request to negotiate version specified in Input version number.



QueryCompatibility = 1

Request to query whether the callee implements a version that is compatible with the version specified in the Input version number by the caller.



QueryNegotiated = 2

Request to query the negotiated version for the caller.