pub enum PartitionIdType {
PeEndpoint {
execution_ctx_count: u16,
},
SepidIndep,
SepidDep {
proxy_endpoint_id: u16,
},
Aux,
}Expand description
Type of partition identified by the partition ID.
Variants
PeEndpoint
Partition ID is a PE endpoint ID. Contains the number of execution contexts implemented by this partition.
SepidIndep
Partition ID is a SEPID for an independent peripheral device.
SepidDep
Partition ID is a SEPID for an dependent peripheral device. Contains the ID of the proxy endpoint for a dependent peripheral device.
Aux
Partition ID is an auxiliary ID.