pub struct PartitionProperties {
pub support_direct_req_rec: bool,
pub support_direct_req_send: bool,
pub support_direct_req2_rec: Option<bool>,
pub support_direct_req2_send: Option<bool>,
pub support_indirect_msg: bool,
pub support_notif_rec: bool,
pub subscribe_vm_created: bool,
pub subscribe_vm_destroyed: bool,
pub is_aarch64: bool,
}Expand description
Properties of a partition.
Fields
support_direct_req_rec: boolThe partition supports receipt of direct requests.
support_direct_req_send: boolThe partition can send direct requests.
support_direct_req2_rec: Option<bool>The partition supports receipt of direct requests via the FFA_MSG_SEND_DIRECT_REQ2 ABI. Added in FF-A v1.2
support_direct_req2_send: Option<bool>The partition can send direct requests via the FFA_MSG_SEND_DIRECT_REQ2 ABI. Added in FF-A v1.2
support_indirect_msg: boolThe partition can send and receive indirect messages.
support_notif_rec: boolThe partition supports receipt of notifications.
subscribe_vm_created: boolThe partition must be informed about each VM that is created by the Hypervisor.
subscribe_vm_destroyed: boolThe partition must be informed about each VM that is destroyed by the Hypervisor.
is_aarch64: boolThe partition runs in the AArch64 execution state.