pub struct BootInfo<'a> {
pub name: BootInfoName<'a>,
pub typ: BootInfoType,
pub contents: BootInfoContents<'a>,
}Expand description
Boot information descriptor.
Fields
name: BootInfoName<'a>typ: BootInfoTypecontents: BootInfoContents<'a>Implementations
Sourceimpl BootInfo<'_>
impl BootInfo<'_>
Sourcepub fn pack(
version: Version,
descriptors: &[BootInfo<'_>],
buf: &mut [u8],
mapped_addr: Option<usize>,
)
pub fn pack( version: Version, descriptors: &[BootInfo<'_>], buf: &mut [u8], mapped_addr: Option<usize>, )
Serialize a list of boot information descriptors into a buffer. The mapped_addr parameter
should contain the address of the buffer in the consumers translation regime (typically a
virtual address where the buffer is mapped to). This is necessary since there are
self-references within the serialized data structure which must be described with an
absolute address according to the FF-A spec.
Sourcepub fn get_blob_size(version: Version, buf: &[u8]) -> Result<usize, Error>
pub fn get_blob_size(version: Version, buf: &[u8]) -> Result<usize, Error>
Get the size of the boot information blob spanning contiguous memory. This enables a consumer to map all of the boot information blob in its translation regime or copy it to another memory location without parsing each element in the boot information descriptor array.