Data structures for describing the parameters of the various FF-A interfaces.
Structs
- Direct
Msg2 Args - Arguments for the
FFA_MSG_SEND_DIRECT_{REQ,RESP}2interfaces. - LogChars
- Generic type for storing
FFA_CONSOLE_LOGcharacter payload and its length in bytes. - MsgSend2
Flags - Flags field of the
FFA_MSG_SEND2interface. - MsgWait
Flags - Flags field of the
FFA_MSG_WAITinterface. - Success
Args Features FFA_FEATURESspecific success argument structure. This type needs further specialization based on ‘FF-A function ID or Feature ID’ field of the preceedingFFA_FEATURESrequest.- Success
Args IdGet FFA_ID_GETspecific success argument structure.- Success
Args SpmId Get FFA_SPM_ID_GETspecific success argument structure.- Target
Info - Endpoint ID and vCPU ID pair, used by
FFA_ERROR,FFA_INTERRUPTandFFA_RUNinterfaces. - Version
Flags - Flags for the
FFA_VERSIONinterface.
Enums
- Console
LogChars - Argument for the
FFA_CONSOLE_LOGinterface. - Direct
MsgArgs - Arguments for the
FFA_MSG_SEND_DIRECT_{REQ,RESP}interfaces. - Feature
- Arguments for the
FFA_FEATURESinterface. - Feature
Id - Feature IDs used by the
FFA_FEATURESinterface. - MemAddr
- Memory address argument for
FFA_MEM_PERM_{GET,SET}interfaces. - MemOp
Buf - Descriptor for a dynamically allocated memory buffer that contains the memory transaction descriptor.
- RxTx
Addr - RXTX buffer descriptor, used by
FFA_RXTX_MAP. - Secondary
EpRegister Addr - Entrypoint address argument for
FFA_SECONDARY_EP_REGISTERinterface. - Success
Args - Generic arguments of the
FFA_SUCCESSinterface. The interpretation of the arguments depends on the interface that initiated the request. The application code has knowledge of the request, so it has to convertSuccessArgsinto/from a specific success args structure that matches the request. - Version
Query Type - Version query types for the
FFA_VERSIONinterface. - VmAvailability
Status - Composite type for capturing success and error return codes for the VM availability messages.
- Warm
Boot Type - Arguments for the Power Warm Boot
FFA_MSG_SEND_DIRECT_REQinterface.
Type Aliases
- Console
LogChars32 - Specialized type for 32-bit
FFA_CONSOLE_LOGpayload. - Console
LogChars64 - Specialized type for 64-bit
FFA_CONSOLE_LOGpayload.