Struct MemTransactionDesc

pub struct MemTransactionDesc {
    pub sender_id: u16,
    pub mem_region_attr: MemRegionAttributes,
    pub flags: MemTransactionFlags,
    pub handle: Handle,
    pub tag: u64,
}
Memory transaction decriptor. Used by an Owner/Lender and a Borrower/Receiver in a transaction to donate, lend or share a memory region.

Fields

sender_id: u16mem_region_attr: MemRegionAttributesflags: MemTransactionFlagshandle: Handletag: u64

Implementations

Source

impl MemTransactionDesc

pub fn pack( &self, constituents: &[ConstituentMemRegion], access_descriptors: &[MemAccessPerm], buf: &mut [u8], ) -> usize

Serialize a memory transaction descriptor and the related constituent memory region descriptors and endpoint memory access permission descriptors into a buffer.

pub fn unpack( buf: &[u8], ) -> Result<(MemTransactionDesc, MemAccessPermIterator<'_>, Option<ConstituentMemRegionIterator<'_>>), Error>

Deserialize a memory transaction descriptor from a buffer and return an interator of the related endpoint memory access permission descriptors and constituent memory region descriptors, if any.